summaryrefslogtreecommitdiffstats
path: root/chrome/browser/mac/scoped_authorizationref.h
diff options
context:
space:
mode:
authormark@chromium.org <mark@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-06-27 16:26:24 +0000
committermark@chromium.org <mark@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-06-27 16:26:24 +0000
commita6e349a6368c997c13512eff8e78304a6e2119b0 (patch)
treef5d6867c9c168cd69ab39c0385bc82b2622c17d7 /chrome/browser/mac/scoped_authorizationref.h
parentde29ac1c0b78c359fef7b642437d58a7f2f83478 (diff)
downloadchromium_src-a6e349a6368c997c13512eff8e78304a6e2119b0.zip
chromium_src-a6e349a6368c997c13512eff8e78304a6e2119b0.tar.gz
chromium_src-a6e349a6368c997c13512eff8e78304a6e2119b0.tar.bz2
Rename scoped_ioobject to ScopedIOObject and put it into its own file. Rename
scoped_AuthorizationRef to ScopedAuthorizationRef. BUG=cleanup TEST=none Review URL: http://codereview.chromium.org/7230022 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@90588 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/mac/scoped_authorizationref.h')
-rw-r--r--chrome/browser/mac/scoped_authorizationref.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/chrome/browser/mac/scoped_authorizationref.h b/chrome/browser/mac/scoped_authorizationref.h
index 2a4c6fe..fbe0b9d 100644
--- a/chrome/browser/mac/scoped_authorizationref.h
+++ b/chrome/browser/mac/scoped_authorizationref.h
@@ -11,16 +11,16 @@
#include "base/basictypes.h"
#include "base/compiler_specific.h"
// scoped_AuthorizationRef maintains ownership of an AuthorizationRef. It is
// patterned after the scoped_ptr interface.
-class scoped_AuthorizationRef {
+class ScopedAuthorizationRef {
public:
- explicit scoped_AuthorizationRef(AuthorizationRef authorization = NULL)
+ explicit ScopedAuthorizationRef(AuthorizationRef authorization = NULL)
: authorization_(authorization) {
}
- ~scoped_AuthorizationRef() {
+ ~ScopedAuthorizationRef() {
if (authorization_) {
AuthorizationFree(authorization_, kAuthorizationFlagDestroyRights);
}
@@ -55,16 +55,16 @@ class scoped_AuthorizationRef {
return authorization_;
}
- void swap(scoped_AuthorizationRef& that) {
+ void swap(ScopedAuthorizationRef& that) {
AuthorizationRef temp = that.authorization_;
that.authorization_ = authorization_;
authorization_ = temp;
}
// scoped_AuthorizationRef::release() is like scoped_ptr<>::release. It is
// NOT a wrapper for AuthorizationFree(). To force a
// scoped_AuthorizationRef object to call AuthorizationFree(), use
// scoped_AuthorizaitonRef::reset().
AuthorizationRef release() WARN_UNUSED_RESULT {
AuthorizationRef temp = authorization_;
authorization_ = NULL;
@@ -74,7 +74,7 @@ class scoped_AuthorizationRef {
private:
AuthorizationRef authorization_;
- DISALLOW_COPY_AND_ASSIGN(scoped_AuthorizationRef);
+ DISALLOW_COPY_AND_ASSIGN(ScopedAuthorizationRef);
};
#endif // CHROME_BROWSER_MAC_SCOPED_AUTHORIZATIONREF_H_
@@ -11,16 +11,16 @@
#include "base/basictypes.h"
#include "base/compiler_specific.h"
-// scoped_AuthorizationRef maintains ownership of an AuthorizationRef. It is
+// ScopedAuthorizationRef maintains ownership of an AuthorizationRef. It is
// patterned after the scoped_ptr interface.
@@ -55,16 +55,16 @@ class scoped_AuthorizationRef {
authorization_ = temp;
}
- // scoped_AuthorizationRef::release() is like scoped_ptr<>::release. It is
+ // ScopedAuthorizationRef::release() is like scoped_ptr<>::release. It is
// NOT a wrapper for AuthorizationFree(). To force a
@@ -55,16 +55,16 @@ class scoped_AuthorizationRef {
// NOT a wrapper for AuthorizationFree(). To force a
- // scoped_AuthorizationRef object to call AuthorizationFree(), use
- // scoped_AuthorizaitonRef::reset().
+ // ScopedAuthorizationRef object to call AuthorizationFree(), use
+ // ScopedAuthorizationRef::reset().
AuthorizationRef release() WARN_UNUSED_RESULT {
AuthorizationRef temp = authorization_;